@@ -4,12 +4,13 @@ use strict;
 use warnings;
 
 use Carp qw(croak);
+use Encode ();
 use JSON;
 use LWP::UserAgent;
 use URI;
 use URI::Escape qw(uri_unescape);
 
-our $VERSION = '0.02';
+our $VERSION = '0.03';
 $VERSION = eval $VERSION;
 
 sub new {
@@ -21,11 +22,13 @@ sub new {
         key => uri_unescape($key),
     }, $class;
 
-    if ($params{ua}) {
-        $self->ua($params{ua});
-    }
-    else {
-        $self->{ua} = LWP::UserAgent->new(agent => "$class/$VERSION");
+    $self->ua(
+        $params{ua} || LWP::UserAgent->new(agent => "$class/$VERSION")
+    );
+
+    if ($params{debug}) {
+        $self->ua->add_handler(request_send  => sub { warn shift->dump; return });
+        $self->ua->add_handler(response_done => sub { warn shift->dump; return });
     }
 
     return $self;
@@ -44,21 +47,29 @@ sub ua {
 sub geocode {
     my $self = shift;
 
-    my $location = @_ % 2 ? $_[0] : $_[0] eq 'location' ? $_[1] : '';
-    return unless $location;
+    my %params   = (@_ % 2) ? (location => shift, @_) : @_;
+    my $location = $params{location} or return;
+    my $country  = $params{country};
+
+    $location = Encode::encode('utf-8', $location);
 
     my $uri = URI->new(
-        'http://platform.beta.mapquest.com/geocoding/v1/address'
+        'http://www.mapquestapi.com/geocoding/v1/address'
+    );
+    $uri->query_form(
+        key      => $self->{key},
+        location => $location,
+        $country ? (adminArea1 => $country) : (),
+
     );
-    $uri->query_form(key => $self->{key}, location => $location);
 
     my $res = $self->ua->get($uri);
     return unless $res->is_success;
 
-    my $data = eval { decode_json($res->decoded_content) };
+    my $data = eval { from_json($res->decoded_content) };
     return unless $data;
 
-    my @results = @{ $data->{locations} || [] };
+    my @results = @{ $data->{results}[0]{locations} || [] };
     return wantarray ? @results : $results[0];
 }
 
@@ -69,7 +80,7 @@ __END__
 
 =head1 NAME
 
-Geo::Coder::Mapquest - Geocode addresses with Mapquest (beta)
+Geo::Coder::Mapquest - Geocode addresses with Mapquest
 
 =head1 SYNOPSIS
 
@@ -82,8 +93,8 @@ Geo::Coder::Mapquest - Geocode addresses with Mapquest (beta)
 
 =head1 DESCRIPTION
 
-The C<Geo::Coder::Mapquest> module provides an interface to the Beta
-Mapquest Geocoding Web Service.
+The C<Geo::Coder::Mapquest> module provides an interface to the Mapquest
+Geocoding Web Service.
 
 =head1 METHODS
 
@@ -104,12 +115,12 @@ object.
     $location = $geocoder->geocode(location => $location)
     @locations = $geocoder->geocode(location => $location)
 
-In scalar context, this method returns the first location result; and in list
-context it returns all locations results.
+In scalar context, this method returns the first location result; and in
+list context it returns all locations results.
 
 Each location result is a hashref; a typical example looks like:
 
-   {
+    {
         adminArea1         => "US",
         adminArea1Type     => "Country",
         adminArea3         => "CA",
@@ -121,9 +132,10 @@ Each location result is a hashref; a typical example looks like:
         displayLatLng      => { lat => "34.10155", lng => "-118.33869" },
         dragPoint          => 0,
         geocodeQuality     => "INTERSECTION",
-        geocodeQualityCode => "I1BAA",
+        geocodeQualityCode => "I1CAA",
         latLng             => { lat => "34.10155", lng => "-118.33869" },
         linkId             => 0,
+        mapUrl             => "http://www.mapquestapi.com/staticmap/v3/getmap?type=map&size=225,160&pois=purple-1,34.10155,-118.33869,0,0|&center=34.10155,-118.33869&zoom=12&key=Dmjtd|lu612ha7ng,ag=o5-5at2u&rand=1659284599",
         postalCode         => 90028,
         sideOfStreet       => "N",
         street             => "Hollywood Blvd & N Highland Ave",
@@ -139,25 +151,25 @@ Accessor for the UserAgent object.
 
 =head1 NOTES
 
-The geocoding results are not production quality at this time. International
-queries produce no results and US addresses frequently only return results
-that are only accurate to the country-level.
-
 An API key can be obtained here:
-L<http://developer.mapquest.com/Home/WhyJoin>.
+L<http://developer.mapquest.com/web/info/account/app-keys>.
+
+After obtaining a key, you must enable the I<Blank Referers> option for the
+account.
 
 Note that Mapquest already url-encodes the key, so the geocoder constructor
 will prevent it from being doubly-encoded. Ensure you do not decode it
 yourself before passing it to the constructor.
 
-After obtaining a key, you must enable the I<Blank Referers> option for the
-account.
+International (non-US) queries do not appear to be fully supported by the
+service at this time.
 
 =head1 SEE ALSO
 
-L<http://platform.beta.mapquest.com/geocoding/>
+L<http://www.mapquestapi.com/geocoding/>
 
-L<Geo::Coder::Bing>, L<Geo::Coder::Google>, L<Geo::Coder::Yahoo>
+L<Geo::Coder::Bing>, L<Geo::Coder::Google>, L<Geo::Coder::Multimap>,
+L<Geo::Coder::Yahoo>
 
 =head1 REQUESTS AND BUGS
 
